@@ -196,13 +196,6 @@ REANA_MAX_CONCURRENT_BATCH_WORKFLOWS = int(
 )
 """Upper limit on concurrent REANA batch workflows running in the cluster."""
 
-REANA_READY_CONDITIONS = {
-    "reana_commons.tasks": [
-        "check_predefined_conditions",
-        "check_running_reana_batch_workflows_count",
-    ]
-}
-
 REANA_LOG_LEVEL = logging.getLevelName(os.getenv("REANA_LOG_LEVEL", "INFO"))
 """Log verbosity level for REANA components."""
 
@@ -362,3 +355,17 @@ HTCONDOR_JOB_FLAVOURS = {
 }
 
 """HTCondor job flavours and their respective runtime in seconds."""
+
+REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES = os.getenv(
+    "REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES", ""
+).split(",")
+"""Keep alive Kubernetes user runtime jobs depending on status.
+
+Keep alive both batch workflow jobs and invididual step jobs after termination
+when their statuses match one of the specified comma-separated values
+(possible values are: ``finished``, ``failed``). By default all jobs are
+cleaned up.
+
+Example: ``REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES="finished,failed"``
+would keep jobs that terminated successfully and jobs that failed.
+"""
